@@ -16,11 +16,13 @@ from robotidy.transformers import load_transformers
 from robotidy.utils import (
     GlobalFormattingConfig,
     split_args_from_name_or_path,
-    remove_rst_formatting
+    remove_rst_formatting,
+    RecommendationFinder
 )
 from robotidy.version import __version__
 
 
+CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 HELP_MSG = f"""
 Version: {__version__}
 
@@ -119,7 +121,7 @@ def find_and_read_config(src_paths: Iterable[str]) -> Dict[str, Any]:
     project_root = find_project_root(src_paths)
     config_path = project_root / 'robotidy.toml'
     if config_path.is_file():
-        return read_robotidy_config(str(config_path))
+        return read_pyproject_config(str(config_path))
     pyproject_path = project_root / 'pyproject.toml'
     if pyproject_path.is_file():
         return read_pyproject_config(str(pyproject_path))
@@ -138,21 +140,16 @@ def load_toml_file(path: str) -> Dict[str, Any]:
 
 
 def read_pyproject_config(path: str) -> Dict[str, Any]:
-    click.echo('Reading pyproject.toml')
+    click.echo(f'Reading {path}')
     config = load_toml_file(path)
     config = config.get("tool", {}).get("robotidy", {})
     return {k.replace('--', '').replace('-', '_'): v for k, v in config.items()}
 
 
-def read_robotidy_config(path: str) -> Dict[str, Any]:
-    config = load_toml_file(path)
-    return {k.replace('--', '').replace('-', '_'): v for k, v in config.items()}
-
-
 def read_config(ctx: click.Context, param: click.Parameter, value: Optional[str]) -> Optional[str]:
     # if --config was not used, try to find pyproject.toml or robotidy.toml file
     if value:
-        config = read_robotidy_config(value)
+        config = read_pyproject_config(value)
     else:
         config = find_and_read_config(ctx.params.get("src", ()))
     if not config:
@@ -172,7 +169,38 @@ def read_config(ctx: click.Context, param: click.Parameter, value: Optional[str]
     ctx.default_map = default_map
 
 
-@click.command(cls=RawHelp, help=HELP_MSG, epilog=EPILOG)
+def print_description(name: str):
+    transformers = load_transformers(None, {}, allow_disabled=True)
+    transformer_by_names = {transformer.__class__.__name__: transformer for transformer in transformers}
+    if name == 'all':
+        for tr_name, transformer in transformer_by_names.items():
+            click.echo(f"Transformer {tr_name}:")
+            click.echo(remove_rst_formatting(transformer.__doc__))
+    elif name in transformer_by_names:
+        click.echo(f"Transformer {name}:")
+        click.echo(remove_rst_formatting(transformer_by_names[name].__doc__))
+    else:
+        rec_finder = RecommendationFinder()
+        similar = rec_finder.find_similar(name, transformer_by_names.keys())
+        click.echo(f"Transformer with the name '{name}' does not exist.{similar}")
+        return 1
+    return 0
+
+
+def print_transformers_list():
+    transformers = load_transformers(None, {}, allow_disabled=True)
+    click.echo('To see detailed docs run --desc <transformer_name> or --desc all. '
+               'Transformers with (disabled) tag \nare executed only when selected explictly with --transform. '
+               'Available transformers:\n')
+    transformer_names = []
+    for transformer in transformers:
+        disabled = ' (disabled)' if not getattr(transformer, 'ENABLED', True) else ''
+        transformer_names.append(transformer.__class__.__name__ + disabled)
+    for name in sorted(transformer_names):
+        click.echo(name)
+
+
+@click.command(cls=RawHelp, help=HELP_MSG, epilog=EPILOG, context_settings=CONTEXT_SETTINGS)
 @click.option(
     '--transform',
     '-t',
@@ -198,10 +226,24 @@ def read_config(ctx: click.Context, param: click.Parameter, value: Optional[str]
     is_eager=True,
     metavar='[PATH(S)]'
 )
+@click.option(
+    "--config",
+    type=click.Path(
+        exists=True,
+        file_okay=True,
+        dir_okay=False,
+        readable=True,
+        allow_dash=False,
+        path_type=str,
+    ),
+    is_eager=True,
+    callback=read_config,
+    help="Read configuration from FILE path.",
+)
 @click.option(
     '--overwrite/--no-overwrite',
     default=True,
-    help='Overwrite source files.',
+    help='Write changes back to file',
     show_default=True
 )
 @click.option(
@@ -226,11 +268,11 @@ def read_config(ctx: click.Context, param: click.Parameter, value: Optional[str]
     show_default=True
 )
 @click.option(
-    '-l',
+    '-ls',
     '--lineseparator',
     type=click.types.Choice(['native', 'windows', 'unix']),
     default='native',
-    help="Line separator to use in outputs. The default is 'native'.\n"
+    help="Line separator to use in outputs.\n"
          "native:  use operating system's native line separators\n"
          "windows: use Windows line separators (CRLF)\n"
          "unix:    use Unix line separators (LF)",
@@ -255,27 +297,6 @@ def read_config(ctx: click.Context, param: click.Parameter, value: Optional[str]
     show_default=True
 )
 @click.option(
-    '-v',
-    '--verbose',
-    is_flag=True,
-    show_default=True
-)
-@click.option(
-    "--config",
-    type=click.Path(
-        exists=True,
-        file_okay=True,
-        dir_okay=False,
-        readable=True,
-        allow_dash=False,
-        path_type=str,
-    ),
-    is_eager=True,
-    callback=read_config,
-    help="Read configuration from FILE path.",
-)
-@click.option(
-    '--list-transformers',
     '--list',
     '-l',
     is_eager=True,
@@ -283,13 +304,42 @@ def read_config(ctx: click.Context, param: click.Parameter, value: Optional[str]
     help='List available transformers and exit.'
 )
 @click.option(
-    '--describe-transformer',
     '--desc',
     '-d',
     default=None,
     metavar='TRANSFORMER_NAME',
     help='Show documentation for selected transformer.'
 )
+@click.option(
+    '--output',
+    '-o',
+    type=click.Path(
+        file_okay=True, dir_okay=False, writable=True, allow_dash=False
+    ),
+    default=None,
+    metavar='PATH',
+    help='Path to output file where source file will be saved'
+)
+@click.option(
+    '-v',
+    '--verbose',
+    is_flag=True,
+    help="More verbose output",
+    show_default=True
+)
+@click.option(  # deprecated
+    '--list-transformers',
+    is_flag=True
+)
+@click.option(  # deprecated
+    '--describe-transformer',
+    default=None
+)
+@click.option(
+    '--force-order',
+    is_flag=True,
+    help='Transform files using transformers in order provided in cli'
+)
 @click.version_option(version=__version__, prog_name='robotidy')
 @click.pass_context
 def cli(
@@ -306,23 +356,27 @@ def cli(
         config: Optional[str],
         startline: Optional[int],
         endline: Optional[int],
+        list: bool,
+        desc: Optional[str],
+        output: Optional[Path],
         list_transformers: bool,
-        describe_transformer: Optional[str]
+        describe_transformer: Optional[str],
+        force_order: bool
 ):
     if list_transformers:
-        transformers = load_transformers(None, {})
-        click.echo('Run --desc <transformer_name> to get more details. Transformers:')
-        for transformer in transformers:
-            click.echo(transformer.__class__.__name__)
+        print('--list-transformers is deprecated in 1.3.0. Use --list instead')
         ctx.exit(0)
-    if describe_transformer is not None:
-        transformers = load_transformers(None, {})
-        transformer_by_names = {transformer.__class__.__name__: transformer for transformer in transformers}
-        if describe_transformer in transformer_by_names:
-            click.echo(f"Transformer {describe_transformer}:")
-            click.echo(remove_rst_formatting(transformer_by_names[describe_transformer].__doc__))
-        else:
-            click.echo(f"Transformer with the name '{describe_transformer}' does not exist")
+    if describe_transformer:
+        print('--describe-transformer is deprecated in 1.3.0. Use --desc NAME instead')
+        ctx.exit(0)
+    if list:
+        print_transformers_list()
+        ctx.exit(0)
+    if desc is not None:
+        return_code = print_description(desc)
+        ctx.exit(return_code)
+    if not src:
+        print("No source path provided. Run robotidy --help to see how to use robotidy")
         ctx.exit(0)
 
     if config and verbose:
@@ -342,7 +396,9 @@ def cli(
         show_diff=diff,
         formatting_config=formatting_config,
         verbose=verbose,
-        check=check
+        check=check,
+        output=output,
+        force_order=force_order
     )
     status = tidy.transform_files()
     ctx.exit(status)
