@@ -1,5 +1,6 @@
 import os
 from typing import List
+import difflib
 
 from robot.api.parsing import (
     ModelVisitor,
@@ -151,3 +152,50 @@ def left_align(node):
 
 def remove_rst_formatting(text):
     return text.replace('::', ':').replace("``", "'")
+
+
+class RecommendationFinder:
+    def find_similar(self, name, candidates):
+        norm_name = name.lower()
+        norm_cand = self.get_normalized_candidates(candidates)
+        matches = self.find(norm_name, norm_cand.keys())
+        if not matches:
+            return ''
+        matches = self.get_original_candidates(matches, norm_cand)
+        suggestion = ' Did you mean:\n'
+        suggestion += '\n'.join(f'    {match}' for match in matches)
+        return suggestion
+
+    def find(self, name, candidates, max_matches=2):
+        """ Return a list of close matches to `name` from `candidates`. """
+        if not name or not candidates:
+            return []
+        cutoff = self._calculate_cutoff(name)
+        return difflib.get_close_matches(
+            name, candidates, n=max_matches, cutoff=cutoff
+        )
+
+    @staticmethod
+    def _calculate_cutoff(string, min_cutoff=.5, max_cutoff=.85,
+                          step=.03):
+        """ The longer the string the bigger required cutoff. """
+        cutoff = min_cutoff + len(string) * step
+        return min(cutoff, max_cutoff)
+
+    @staticmethod
+    def get_original_candidates(candidates, norm_candidates):
+        """ Map found normalized candidates to unique original candidates. """
+        return sorted(list(set(c for cand in candidates for c in norm_candidates[cand])))
+
+    @staticmethod
+    def get_normalized_candidates(candidates):
+        norm_cand = {cand.lower(): [cand] for cand in candidates}
+        # most popular typos
+        norm_cand['align'] = ['AlignSettingsSection', 'AlignVariablesSection']
+        norm_cand['normalize'] = ['NormalizeAssignments', 'NormalizeNewLines', 'NormalizeSectionHeaderName',
+                                  'NormalizeSeparators', 'NormalizeSettingName']
+        norm_cand['order'] = ['OrderSettings', 'OrderSettingsSection']
+        norm_cand['alignsettings'] = ['AlignSettingsSection']
+        norm_cand['alignvariables'] = ['AlignVariablesSection']
+        norm_cand['assignmentnormalizer'] = ['NormalizeAssignments']
+        return norm_cand
